@@ -5,6 +5,8 @@ function(xdata,ydata,date,t,rts,g,w=NULL,sg="ssm",ftype="d"){
   if(is.na(match(rts,c("crs","vrs","irs","drs")))){stop('rts must be "crs", "vrs", "irs", or "drs".')}
   if(is.na(match(sg,c("ssm","max","min")))){stop('sg must be "ssm", "max", or "min".')}
   if(is.na(match(ftype,c("d","s")))){stop('ftype must be either "d" or "s".')}
+  if(t<=min(date)){stop('t is earlier than dataset.')}
+  if(max(date)<=t){stop('t is later than dataset.')}
   
   # Parameters
   n<-nrow(xdata); m<-ncol(xdata); s<-ncol(ydata)
